@@ -385,7 +385,6 @@ async def next_cmd(
     ...         SnmpDispatcher(),
     ...         CommunityData('public'),
     ...         await UdpTransportTarget.create(('demo.pysnmp.com', 161)),
-    ...         ContextData(),
     ...         ObjectType(ObjectIdentity('SNMPv2-MIB', 'system'))
     ...     )
     ...     print(errorIndication, errorStatus, errorIndex, varBinds)
@@ -478,7 +477,7 @@ async def bulk_cmd(
         associated state information.
 
     authData: :py:class:`~pysnmp.hlapi.v1arch.asyncio.CommunityData`
-        Class instance representing SNMPv1/v2c credentials.
+        Class instance representing SNMPv2c credentials. (SNMPv1 / mpModel=0 is not allowed)
 
     transportTarget: :py:class:`~pysnmp.hlapi.v1arch.asyncio.UdpTransportTarget` or
         :py:class:`~pysnmp.hlapi.v1arch.asyncio.Udp6TransportTarget` Class instance representing
@@ -518,31 +517,20 @@ async def bulk_cmd(
     errorIndex: int
         Non-zero value refers to `varBinds[errorIndex-1]`
     varBindTable: tuple
-        A sequence of sequences (e.g. 2-D array) of OID-value pairs in form
-        of base SNMP types (if `lookupMib` is `False`) or
-        :py:class:`~pysnmp.smi.rfc1902.ObjectType` class instances (if
-        `lookupMib` is `True`) a table of MIB variables returned in SNMP
-        response, with up to `maxRepetitions` rows, i.e.
-        `len(varBindTable) <= maxRepetitions`.
+        A flat sequence of variables returned in the SNMP GETBULK
+        response. If ``lookupMib`` is ``True``, elements are
+        :py:class:`~pysnmp.smi.rfc1902.ObjectType` instances; otherwise
+        they are OID-value pairs of base types. The order is the raw
+        wire order: first the non-repeaters (at most one each), then up
+        to ``maxRepetitions`` groups of the repeaters in request order.
 
-        For `0 <= i < len(varBindTable)` and `0 <= j < len(varBinds)`,
-        `varBindTable[i][j]` represents:
-
-        - For non-repeaters (`j < nonRepeaters`), the first lexicographic
-          successor of `varBinds[j]`, regardless the value of `i`, or an
-          :py:class:`~pysnmp.smi.rfc1902.ObjectType` instance with the
-          :py:obj:`~pysnmp.proto.rfc1905.endOfMibView` value if no such
-          successor exists;
-        - For repeaters (`j >= nonRepeaters`), the `i`-th lexicographic
-          successor of `varBinds[j]`, or an
-          :py:class:`~pysnmp.smi.rfc1902.ObjectType` instance with the
-          :py:obj:`~pysnmp.proto.rfc1905.endOfMibView` value if no such
-          successor exists.
+        The maximum length is
+        ``nonRepeaters + maxRepetitions * (len(varBinds) - nonRepeaters)``,
+        but the agent may return fewer items (e.g., due to
+        :py:obj:`~pysnmp.proto.rfc1905.endOfMibView` or truncation).
 
         See :rfc:`3416#section-4.2.3` for details on the underlying
-        `GetBulkRequest-PDU` and the associated `GetResponse-PDU`, such as
-        specific conditions under which the server may truncate the response,
-        causing `varBindTable` to have less than `maxRepetitions` rows.
+        ``GetBulkRequest-PDU`` and the associated ``GetResponse-PDU``.
 
     Raises
     ------
@@ -566,7 +554,7 @@ async def bulk_cmd(
     ...     print(errorIndication, errorStatus, errorIndex, varBinds)
     >>>
     >>> asyncio.run(run())
-    (None, 0, 0, [[ObjectType(ObjectIdentity(ObjectName('1.3.6.1.2.1.1.1.0')), DisplayString('SunOS zeus.pysnmp.com 4.1.3_U1 1 sun4m'))], [ObjectType(ObjectIdentity(ObjectName('1.3.6.1.2.1.1.2.0')), ObjectIdentifier('1.3.6.1.4.1.424242.1.1'))]])
+    (None, 0, 0, [ObjectType(ObjectIdentity(ObjectName('1.3.6.1.2.1.1.1.0')), DisplayString('SunOS zeus.pysnmp.com 4.1.3_U1 1 sun4m')), ObjectType(ObjectIdentity(ObjectName('1.3.6.1.2.1.1.2.0')), ObjectIdentifier('1.3.6.1.4.1.424242.1.1'))])
     >>>
     """
 
@@ -838,7 +826,7 @@ async def bulk_walk_cmd(
         Class instance representing SNMP engine.
 
     authData : :py:class:`~pysnmp.hlapi.v1arch.asyncio.CommunityData`
-        Class instance representing SNMP credentials.
+        Class instance representing SNMPv2c credentials. (SNMPv1 / mpModel=0 is not allowed)
 
     transportTarget : :py:class:`~pysnmp.hlapi.v1arch.asyncio.UdpTransportTarget` or :py:class:`~pysnmp.hlapi.v1arch.asyncio.Udp6TransportTarget`
         Class instance representing transport type along with SNMP peer address.
@@ -948,13 +936,17 @@ async def bulk_walk_cmd(
             maxRepetitions = min(maxRepetitions, maxRows - totalRows)
 
         if varBinds:
+            # Create a simple tuple with the OID from the previous response and Null value
+            # This approach matches walk_cmd() and works with both lookupMib=True and False
+            nextVarBinds = [(varBinds[-1][0], Null(""))]
+
             errorIndication, errorStatus, errorIndex, varBindTable = await bulk_cmd(
                 dispatcher,
                 authData,
                 transportTarget,
                 nonRepeaters,
                 maxRepetitions,
-                *[ObjectType(varBinds[-1][0], Null(""))],
+                *nextVarBinds,
                 **dict(lookupMib=options.get("lookupMib", True)),
             )
 
