@@ -6,7 +6,7 @@
 #
 from pysnmp.proto import rfc1157, rfc1905
 
-readClassPDUs = {
+READ_CLASS_PDUS = {
     rfc1157.GetRequestPDU.tagSet: 1,
     rfc1157.GetNextRequestPDU.tagSet: 1,
     rfc1905.GetRequestPDU.tagSet: 1,
@@ -14,23 +14,23 @@ readClassPDUs = {
     rfc1905.GetBulkRequestPDU.tagSet: 1,
 }
 
-writeClassPDUs = {rfc1157.SetRequestPDU.tagSet: 1, rfc1905.SetRequestPDU.tagSet: 1}
+WRITE_CLASS_PDUS = {rfc1157.SetRequestPDU.tagSet: 1, rfc1905.SetRequestPDU.tagSet: 1}
 
-responseClassPDUs = {
+RESPONSE_CLASS_PDUS = {
     rfc1157.GetResponsePDU.tagSet: 1,
     rfc1905.ResponsePDU.tagSet: 1,
     rfc1905.ReportPDU.tagSet: 1,
 }
 
-notificationClassPDUs = {
+NOTIFICATION_CLASS_PDUS = {
     rfc1157.TrapPDU.tagSet: 1,
     rfc1905.SNMPv2TrapPDU.tagSet: 1,
     rfc1905.InformRequestPDU.tagSet: 1,
 }
 
-internalClassPDUs = {rfc1905.ReportPDU.tagSet: 1}
+INTERNAL_CLASS_PDUS = {rfc1905.ReportPDU.tagSet: 1}
 
-confirmedClassPDUs = {
+CONFIRMED_CLASS_PDUS = {
     rfc1157.GetRequestPDU.tagSet: 1,
     rfc1157.GetNextRequestPDU.tagSet: 1,
     rfc1157.SetRequestPDU.tagSet: 1,
@@ -41,7 +41,7 @@ confirmedClassPDUs = {
     rfc1905.InformRequestPDU.tagSet: 1,
 }
 
-unconfirmedClassPDUs = {
+UNCONFIRMED_CLASS_PDUS = {
     rfc1157.GetResponsePDU.tagSet: 1,
     rfc1905.ResponsePDU.tagSet: 1,
     rfc1157.TrapPDU.tagSet: 1,
